import { EthereumProviderConfig } from "./interfaces";
export declare const LOCALHOST = "localhost";
export declare const CONTRACT_TYPE_ETH = "eth";
export declare const CONTRACT_TYPE_ERC20 = "erc20";
export declare const CONTRACT_TYPE_ERC721 = "erc721";
export declare const CONTRACT_TYPE_ERC1155 = "erc1155";
export declare const ERC1155_INTERFACE_ID = "0xd9b67a26";
export declare const ERC721_INTERFACE_ID = "0x80ac58cd";
export declare const ERC721_METADATA_INTERFACE_ID = "0x5b5e139f";
export declare const ERC721_ENUMERABLE_INTERFACE_ID = "0x780e9d63";
export declare const MAINNET_CHAIN_ID = "0x1";
export declare const POLYGON_CHAIN_ID = "0x89";
export declare const BSC_MAINNET_CHAIN_ID = "0x38";
export declare const AVALANCHE_MAINNET_CHAIN_ID = "0xa86a";
export declare const XDAI_CHAIN_ID = "0x64";
export declare const ARBITRUM_MAINNET_CHAIN_ID = "0xa4b1";
export declare const OPTIMISM_MAINNET_CHAIN_ID = "0xa";
export declare const CELO_MAINNET_CHAIN_ID = "0xa4ec";
export declare const BASE_CHAIN_ID = "0x2105";
export declare const LINEA_CHAIN_ID = "0xe708";
export declare const SEPOLIA_CHAIN_ID = "0xaa36a7";
export declare const POLYGON_AMOY_CHAIN_ID = "0x13882";
export declare const BSC_TESTNET_CHAIN_ID = "0x61";
export declare const AVALANCHE_TESTNET_CHAIN_ID = "0xa869";
export declare const ARBITRUM_TESTNET_CHAIN_ID = "0x66eee";
export declare const OPTIMISM_TESTNET_CHAIN_ID = "0xaa37dc";
export declare const BASE_TESTNET_CHAIN_ID = "0x14a34";
export declare const LINEA_SEPOLIA_CHAIN_ID = "0xe705";
export declare const SUPPORTED_NETWORKS: Record<string, EthereumProviderConfig>;
export declare const METHOD_TYPES: {
    readonly GET_ACCOUNTS: "eth_accounts";
    readonly ETH_TRANSACTION: "eth_sendTransaction";
    readonly ETH_SIGN_TRANSACTION: "eth_signTransaction";
    readonly ETH_ESTIMATE_AA_TRANSACTION_GAS: "eth_estimateAATransactionGas";
    readonly ETH_ESTIMATE_USER_OPERATION_GAS: "eth_estimateUserOperationGas";
    readonly ETH_GET_SUPPORTED_ENTRY_POINTS: "eth_supportedEntryPoints";
    readonly ETH_GET_USER_OPERATION: "eth_getUserOperationByHash";
    readonly ETH_GET_USER_OPERATION_RECEIPT: "eth_getUserOperationReceipt";
    readonly ETH_SEND_USER_OPERATION: "eth_sendUserOperation";
    readonly PIMLICO_GET_USER_OPERATION_GAS_PRICE: "pimlico_getUserOperationGasPrice";
    readonly PIMLICO_GET_USER_OPERATION_STATUS: "pimlico_getUserOperationStatus";
    readonly PIMLICO_SIMULATE_ASSET_CHANGES: "pimlico_simulateAssetChanges";
    readonly BICONOMY_GET_GAS_FEE_VALUES: "biconomy_getGasFeeValues";
    readonly BICONOMY_GET_USER_OPERATION_STATUS: "biconomy_getUserOperationStatus";
    readonly ETH_GET_PAYMASTER_DATA: "pm_getPaymasterData";
    readonly ETH_GET_PAYMASTER_STUB_DATA: "pm_getPaymasterStubData";
    readonly ETH_SPONSOR_USER_OPERATION: "pm_sponsorUserOperation";
    readonly ETH_GET_FEE_QUOTE_OR_DATA: "pm_getFeeQuoteOrData";
    readonly PIMLICO_GET_TOKEN_QUOTES: "pimlico_getTokenQuotes";
    readonly ETH_REQUEST_ACCOUNTS: "eth_requestAccounts";
    readonly ETH_SEND_RAW_TRANSACTION: "eth_sendRawTransaction";
    readonly ETH_SIGN: "eth_sign";
    readonly ETH_SIGN_TYPED_DATA_V4: "eth_signTypedData_v4";
    readonly PERSONAL_SIGN: "personal_sign";
    readonly ETH_GET_TRANSACTION_COUNT: "eth_getTransactionCount";
    readonly ETH_GET_TRANSACTION_BY_HASH: "eth_getTransactionByHash";
    readonly ETH_GET_TRANSACTION_RECEIPT: "eth_getTransactionReceipt";
    readonly WATCH_ASSET: "wallet_watchAsset";
    readonly ETH_GET_BLOCK_BY_HASH: "eth_getBlockByHash";
    readonly ETH_GET_CODE: "eth_getCode";
    readonly ETH_GET_GAS_PRICE: "eth_gasPrice";
    readonly ETH_PRIVATE_KEY: "eth_privateKey";
    readonly PRIVATE_KEY: "private_key";
    readonly ETH_PUBLIC_KEY: "eth_publicKey";
    readonly PUBLIC_KEY: "public_key";
    readonly SWITCH_CHAIN: "wallet_switchEthereumChain";
    readonly ADD_CHAIN: "wallet_addEthereumChain";
};
export declare const BUNDLER_METHOD_TYPES: readonly ["eth_estimateUserOperationGas", "eth_supportedEntryPoints", "eth_getUserOperationByHash", "eth_getUserOperationReceipt", "eth_sendUserOperation", "pimlico_getUserOperationGasPrice", "pimlico_getUserOperationStatus", "pimlico_simulateAssetChanges", "biconomy_getGasFeeValues", "biconomy_getUserOperationStatus"];
export declare const PAYMASTER_METHOD_TYPES: readonly ["pm_getPaymasterData", "pm_getPaymasterStubData", "pm_sponsorUserOperation", "pimlico_getTokenQuotes", "pm_getFeeQuoteOrData"];
export declare const TRANSACTION_ENVELOPE_TYPES: {
    readonly LEGACY: "0x0";
    readonly ACCESS_LIST: "0x1";
    readonly FEE_MARKET: "0x2";
};
export declare const GAS_ESTIMATE_TYPES: {
    readonly FEE_MARKET: "fee-market";
    readonly LEGACY: "legacy";
    readonly ETH_GASPRICE: "eth_gasPrice";
    readonly NONE: "none";
};
export declare const CHAIN_ID_TO_GAS_LIMIT_BUFFER_MAP: Record<string, number>;
export declare const OLD_ERC721_LIST: Record<string, {
    name?: string;
    logo?: string;
    erc20?: boolean;
    symbol?: string;
    decimals?: number;
}>;
export declare const TEST_CHAINS: string[];
export declare const MM_TOKEN_API_SUPPORTED_CHAINS: string[];
export declare const MM_NFT_API_SUPPORTED_CHAINS: string[];
export declare const COINGECKO_SUPPORTED_CURRENCIES: Set<string>;
export declare const COINGECKO_PLATFORMS_CHAIN_CODE_MAP: Record<string, {
    platform: string;
    currency: string;
}>;
export declare const SMART_ACCOUNT: {
    readonly BICONOMY: "biconomy";
    readonly KERNEL: "kernel";
    readonly SAFE: "safe";
    readonly TRUST: "trust";
    readonly LIGHT: "light";
    readonly SIMPLE: "simple";
    readonly NEXUS: "nexus";
    readonly METAMASK: "metamask";
};
